@@ -1,8 +1,14 @@
 # -*- coding: utf-8 -*-
 import re
-from html import _escape_map_full
 from html.entities import codepoint2name
 
+try:
+    from html import _escape_map_full
+except:
+    # taken from the 3.3 standard lib, as it's removed in 3.4
+    _escape_map_full = {ord('&'): '&amp;', ord('<'): '&lt;', ord('>'): '&gt;',
+                        ord('"'): '&quot;', ord('\''): '&#x27;'}
+
 html_entities = {_ord: '&{0};'.format(value)
                  for _ord, value in codepoint2name.items()}
 html_entities.update(_escape_map_full)
